@@ -1,9 +1,10 @@
-import pyfiglet
 import pyprocar
 
 
 def welcome():
-    print(pyfiglet.figlet_format("PyProcar"))
+    print(
+        " ____        ____\n|  _ \ _   _|  _ \ _ __ ___   ___ __ _ _ __ \n| |_) | | | | |_) | '__/ _ \ / __/ _` | '__|\n|  __/| |_| |  __/| | | (_) | (_| (_| | |   \n|_|    \__, |_|   |_|  \___/ \___\__,_|_|\n       |___/"
+    )
     print("A Python library for electronic structure pre/post-processing.\n")
     print("Version %s created on %s\n" % (pyprocar.__version__, pyprocar.__date__))
     print(
